@@ -40,7 +40,7 @@ def job_commands():
 @click.option('-r', '--run', help='Create and run the job.', is_flag=True)
 @click.option('-w', '--wait', help='Wait for the job to finish.', is_flag=True)
 @click.option('-cit', '--instance-type',
-              help="Cluster instance type, options are: -s (small - default), -m (meduim), -l (large).",
+              help="Cluster instance type, options are: -s (small - default), -m (medium), -l (large).",
               type=click.Choice(['s', 'm', 'l']), default='s')
 @click.option('-cid', '--cluster-id', help="Cluster id to run the job on. "
                                            "You can use the ‘cluster list’ command to view your clusters. "
@@ -112,7 +112,7 @@ def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wa
         return
 
     try:
-        show_progress_bar = not state.quite_mode
+        show_progress_bar = not state.quiet_mode
         const_file_ids, local_input_file_ids = upload_job_files(input_paths, const_paths, cluster, show_progress_bar)
         input_file_ids += local_input_file_ids
 
